--[[
###############
Inked: keivamp#
###############
]]--
local AddOnName, Engine = ...

local _G = _G
local math_max = _G.math.max
local math_min = _G.math.min
local next = _G.next
local pairs = _G.pairs
local select = _G.select
local string_format = _G.string.format
local string_lower = _G.string.lower
local table_insert = _G.table.insert
local tonumber = _G.tonumber
local unpack = _G.unpack
local BAG_ITEM_QUALITY_COLORS = _G.BAG_ITEM_QUALITY_COLORS
local CUSTOM_CLASS_COLORS = _G.CUSTOM_CLASS_COLORS
local CombatLogGetCurrentEventInfo = _G.CombatLogGetCurrentEventInfo
local CreateFrame = _G.CreateFrame
local GetAddOnEnableState = _G.GetAddOnEnableState
local GetAddOnInfo = _G.GetAddOnInfo
local GetAddOnMetadata = _G.GetAddOnMetadata
local GetBuildInfo = _G.GetBuildInfo
local GetLocale = _G.GetLocale
local GetNumAddOns = _G.GetNumAddOns
local GetPhysicalScreenSize = _G.GetPhysicalScreenSize
local GetRealmName = _G.GetRealmName
local LOCALIZED_CLASS_NAMES_MALE = _G.LOCALIZED_CLASS_NAMES_MALE
local LibStub = _G.LibStub
local RAID_CLASS_COLORS = _G.RAID_CLASS_COLORS
local UnitClass = _G.UnitClass
local UnitFactionGroup = _G.UnitFactionGroup
local UnitGUID = _G.UnitGUID
local UnitLevel = _G.UnitLevel
local UnitName = _G.UnitName
local UnitRace = _G.UnitRace

-- Engine
Engine[1] = {} 
--Engine[2] = {} 
--Engine[3] = {} 

local Ink = unpack(Engine)

-- Deprecated
LE_ITEM_QUALITY_POOR = Enum.ItemQuality.Poor
LE_ITEM_QUALITY_COMMON = Enum.ItemQuality.Common
LE_ITEM_QUALITY_UNCOMMON = Enum.ItemQuality.Uncommon
LE_ITEM_QUALITY_RARE = Enum.ItemQuality.Rare
LE_ITEM_QUALITY_EPIC = Enum.ItemQuality.Epic
LE_ITEM_QUALITY_LEGENDARY = Enum.ItemQuality.Legendary
LE_ITEM_QUALITY_ARTIFACT = Enum.ItemQuality.Artifact
LE_ITEM_QUALITY_HEIRLOOM = Enum.ItemQuality.Heirloom

-- Ink.oUF = Engine.oUF
Ink.cargBags = Engine.cargBags
Ink.Unfit = LibStub("Unfit-1.0")
Ink.libButtonGlow = LibStub("LibButtonGlow-1.0", true)

Ink.AddOns = {}
Ink.AddOnVersion = {}

Ink.Title = GetAddOnMetadata(AddOnName, "Title")
Ink.Version = GetAddOnMetadata(AddOnName, "Version")

Ink.Name = UnitName("player")
Ink.Class = select(2, UnitClass("player"))
Ink.Race = UnitRace("player")
Ink.Faction = UnitFactionGroup("player")
Ink.Level = UnitLevel("player")
Ink.Client = GetLocale()
Ink.Realm = GetRealmName()
Ink.Media = "Interface\\AddOns\\Inked\\Graphics\\"
Ink.LSM = LibStub and LibStub:GetLibrary("LibSharedMedia-3.0", true)
Ink.ScreenWidth, Ink.ScreenHeight = GetPhysicalScreenSize()
Ink.Resolution = string_format("%dx%d", Ink.ScreenWidth, Ink.ScreenHeight)
Ink.TexCoords = {0.08, 0.92, 0.08, 0.92}
Ink.SystemColor = "|CFFFFeC66"

Ink.Pop = function()
	return
end

local events = {}
local host = CreateFrame("Frame")
local modules, initQueue = {}, {}

host:SetScript("OnEvent", function(_, event, ...)
	for func in pairs(events[event]) do
		if event == "COMBAT_LOG_EVENT_UNFILTERED" then
			func(event, CombatLogGetCurrentEventInfo())
		else
			func(event, ...)
		end
	end
end)

function Ink:RegisterEvent(event, func, unit1, unit2)
	if not events[event] then
		events[event] = {}
		if unit1 then
			host:RegisterUnitEvent(event, unit1, unit2)
		else
			host:RegisterEvent(event)
		end
	end

	events[event][func] = true
end

function Ink:UnregisterEvent(event, func)
	local funcs = events[event]
	if funcs and funcs[func] then
		funcs[func] = nil
		if not next(funcs) then
			events[event] = nil
			host:UnregisterEvent(event)
		end
	end
end

function Ink:NewModule(name)
	if modules[name] then
		Ink.Print("Module ["..name.."] has already been registered.")
		return
	end

	local module = {}
	module.name = name
	modules[name] = module

	table_insert(initQueue, module)

	return module
end

function Ink:GetModule(name)
	if not modules[name] then
		Ink.Print("Module <"..name.."> does not exist.")
		return
	end

	return modules[name]
end

local function GetBestScale()
	local scale = math_max(0.4, math_min(1.15, 768 / Ink.ScreenHeight))
	return Ink.Round(scale, 2)
end

function Ink:SetupUIScale(init)
	
end

local isScaling = false
local function UpdatePixelScale(event)
	if isScaling then
		return
	end
	isScaling = true

	if event == "UI_SCALE_CHANGED" then
		Ink.ScreenWidth, Ink.ScreenHeight = GetPhysicalScreenSize()
	end



	isScaling = false
end

Ink:RegisterEvent("PLAYER_LOGIN", function()

	Ink:RegisterEvent("UI_SCALE_CHANGED", UpdatePixelScale)

	for _, module in next, initQueue do
		if module.OnEnable then
			module:OnEnable()
		else
			Ink.Print("Module ["..module.name.."] failed to load!")
		end
	end

	Ink.Modules = modules
end)

local SetLoginMessage;
do
 
    local commandments = {
        {
             "Hello There",
            "Greetings",
            "Welcome",
            "Let's get ready to Warcraft",
            "Ready to Play",
			"Hi",
            "Hey",
            "*Waves*",
            "Time for a quest",
            "We got this",
			"Yo",
			"Party Time",
			"Let's Go",
			"Rock - N - Roll",
			"Greatness has arrived!!",
			"Power Up!!",
			"You Have Been Inked",
        },
  
    };
    local messagePattern = "|cffFF2F00%s:|r";
    local debugPattern = "|cffFF2F00%s|r [|cff992FFF%s|r]|cffFF2F00:|r";
    local testPattern = "Version |cffAA78FF%s|r, Build |cffAA78FF%s|r."

    local function _send_message(msg)
        if(type(msg) == "table") then
             msg = tostring(msg)
        end
        if(not msg) then return end
        
            print(msg)
     
    end

    SetLoginMessage = function(self)
   
        local preschat1 = (" ")
        _send_message(preschat1)
		local preschat2 = (" ")
        _send_message(preschat2)
		local preschat3 = (" ")
        _send_message(preschat3)
        local first = commandments[1][random(1,17)]     
		local login_msg1 = (first)
        _send_message(login_msg1)
		local login_msg2 = (" ")
        _send_message(login_msg2)
		 local login_msg3 = (Ink.Title.." Version:  "..Ink.Version)
        _send_message(login_msg3)
		 local login_msg4 = ("/Inked /Ink /nk to pull up the Config window")
        _send_message(login_msg4)
		local login_msg5 = ("/rl to reload the Interface")
        _send_message(login_msg5)
		local login_msg6 = ("Made by that noob keivamp (Kay - Vamp)")
        _send_message(login_msg6)
		local postchat1 = (" ")
        _send_message(postchat1)
    end

   
end

Ink:RegisterEvent("VARIABLES_LOADED", function(event)
	Ink.GUID = UnitGUID("player")
	Ink:UnregisterEvent(event)
end)

Ink:RegisterEvent("PLAYER_LEVEL_UP", function(_, level)
	if not Ink.Level then
		return
	end

	Ink.Level = level
end)

for i = 1, GetNumAddOns() do
	local Name = GetAddOnInfo(i)
	Ink.AddOns[string_lower(Name)] = GetAddOnEnableState(Ink.Name, Name) == 2
	Ink.AddOnVersion[string_lower(Name)] = GetAddOnMetadata(Name, "Version")
end

local InkedLoginFrame=CreateFrame("Frame")
		InkedLoginFrame:RegisterEvent("PLAYER_LOGIN")
		InkedLoginFrame:RegisterEvent("CINEMATIC_STOP")
		InkedLoginFrame:SetScript("OnEvent", function(self, event) 
		
		
			SetLoginMessage(self);											
		end)
		
_G[AddOnName] = Engine